@@ -1,6 +1,6 @@
 package Sub::Spec::HTTP::Server;
 BEGIN {
-  $Sub::Spec::HTTP::Server::VERSION = '0.03';
+  $Sub::Spec::HTTP::Server::VERSION = '0.04';
 }
 # ABSTRACT: Serve subroutine calls via HTTP/HTTPS
 
@@ -389,9 +389,21 @@ sub get_sub_name {
     my ($self) = @_;
     my $req = $self->req;
     my $http_req = $req->{http_req};
-    $log->trace("request URI = ".$http_req->uri);
+
+    if ($http_req->header('X-SS-Log-Level')) {
+        $req->{log_level} = $http_req->header('X-SS-Log-Level');
+        $log->trace("Turning on chunked transfer ...");
+        $req->{chunked}++;
+    }
+    if ($http_req->header('X-SS-Mark-Chunk')) {
+        $log->trace("Turning on mark prefix on each chunk ...");
+        $req->{mark_chunk}++;
+        $log->trace("Turning on chunked transfer ...");
+        $req->{chunked}++;
+    }
 
     my $uri = $http_req->uri;
+    $log->trace("request URI = $uri");
     unless ($uri =~ m!\A/+v1
                       /+([^/]+(?:/+[^/]+)*) # module
                       /+([^/]+?)    # func
@@ -465,14 +477,6 @@ sub get_sub_name {
             $http_req->header('X-SS-Log-Level' => $level) if $level;
         }
     }
-    if ($http_req->header('X-SS-Log-Level')) {
-        $req->{log_level} = $http_req->header('X-SS-Log-Level');
-        $req->{chunked}++;
-    }
-    if ($http_req->header('X-SS-Mark-Chunk')) {
-        $req->{mark_chunk}++;
-        $req->{chunked}++;
-    }
     $log->trace("parse request URI: module=$module, sub=$sub, opts=$opts");
 }
 
@@ -789,7 +793,7 @@ Sub::Spec::HTTP::Server - Serve subroutine calls via HTTP/HTTPS
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
